The Ur-Quan Masters Discussion Forum

The Ur-Quan Masters Re-Release => Technical Issues => Topic started by: SC2ForLife on March 09, 2007, 05:15:10 am



Title: 3DO Intro revisited
Post by: SC2ForLife on March 09, 2007, 05:15:10 am
This is a much asked topic so I thought I would share how I did it :)

Step 1 is to download the two files below
http://www.angelfire.com/planet/zfighterjoebob/uncdrom.zip (copy and paste)
http://www.magiciso.com/Setup_MagicISO.exe

Step 2 is to install MagicISO and make the .iso image of SC2, name it anything you want.

Step 3 is to unzip UnCDRom and place it somewhere you can find easily (Desktop works)

Step 4, drag the .iso image into the UNCD-ROM.exe file and it will begin the extraction. It extracted them into My Documents for me but I have not tried on another PC so just search for a .duk file and you should find it.

Step 5 is to create the appropriate folders in the UQM folder based on this guide; http://uqm.stack.nl/wiki/The_Ur-Quan_Masters_Technical_FAQ#How_do_I_use_the_3DO_intro_and_victory_movies_in_the_game.3F
and move the appropriate files.

This is exactly what I did and it worked fine.


Title: Re: 3DO Intro revisited
Post by: Novus on March 09, 2007, 08:49:17 am
Speaking of 3DO videos, it seems my patch for the 3DO ship information videos has hit UQM SVN (via Michael). As the bug database is still down, I'm reporting my comments here:

You no longer need to convert AIFF audio to WAV (thanks to Alex's AIFF decoder), as soon as you fix a minor detail that has been overlooked; UQM currently loads the ship description speech from a WAV instead of an AIFF. This is easily fixed:

Code:
--- /home/jan/uqm-svn/sc2/sc2/src/sc2code/libs/video/video.c    (revision 2712)
+++ /home/jan/uqm-svn/sc2/sc2/src/sc2code/libs/video/video.c    (working copy)
@@ -143,13 +143,13 @@
        vid->h = vid->decoder->h;
        vid->guard = CreateMutex ("video guard", SYNC_CLASS_VIDEO);
 
/* Override main sound with .wav if available. */
        filename = HMalloc (strlen (pStr) + 5);
        strcpy (filename, pStr);
        pext = strrchr (filename, '.');
        if (pext)
               *pext = 0;
-       strcat (filename, ".wav");
+       strcat (filename, ".aif");
        altsound = LoadMusicFile (filename);
        if (altsound != 0) {
               DestroyMusic (vid->hAudio);
@@ -143,13 +143,13 @@
        vid->guard = CreateMutex ("video guard", SYNC_CLASS_VIDEO);
 
-       /* Override main sound with .wav if available. */
+       /* Override main sound with .aif if available. */
        filename = HMalloc (strlen (pStr) + 5);
        strcpy (filename, pStr);

Installation is simple if you have the 3DO CD extracted already: just copy ship*.* and spin.aif from duckart on the CD to content/slides/spins/ in the UQM directory hierarchy.

Edit: Uh... Usage instructions? Oh yeah, right, right... Select a ship in Melee fleet setup or the shipyard and press the Menu special button (defaults to [Alt]). Uh... I, uh, I guess that's it.